summaryrefslogtreecommitdiffstats
path: root/media/ffmpeg/ffmpeg_common.h
diff options
context:
space:
mode:
Diffstat (limited to 'media/ffmpeg/ffmpeg_common.h')
-rw-r--r--media/ffmpeg/ffmpeg_common.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/media/ffmpeg/ffmpeg_common.h b/media/ffmpeg/ffmpeg_common.h
index 6f04e07..dec47df 100644
--- a/media/ffmpeg/ffmpeg_common.h
+++ b/media/ffmpeg/ffmpeg_common.h
@@ -105,10 +105,10 @@ MEDIA_EXPORT bool GetStreamByteCountOverRange(AVStream* stream,
base::TimeDelta* range_start,
base::TimeDelta* range_end);
// Calculates the natural width and height of the video using the video's
// encoded dimensions and sample_aspect_ratio.
-int GetNaturalHeight(AVStream* stream);
-int GetNaturalWidth(AVStream* stream);
+int GetSurfaceHeight(AVStream* stream);
+int GetSurfaceWidth(AVStream* stream);
// Closes & destroys all AVStreams in the context and then closes &
// destroys the AVFormatContext.
@@ -105,10 +105,10 @@ MEDIA_EXPORT bool GetStreamByteCountOverRange(AVStream* stream,
base::TimeDelta* range_start,
base::TimeDelta* range_end);
-// Calculates the natural width and height of the video using the video's
+// Calculates the width and height of the video surface using the video's
// encoded dimensions and sample_aspect_ratio.